@@ -129,19 +129,28 @@ def get_document():
     # print(template)
     return Document(template)
 
+def get_custom_document(filepath: str):
+    try:
+        return Document(filepath)
+    except:
+        if sg.popup_yes_no('Criticus failed to open the custom template.\nWould you like to use the default template instead?', title='Failed to Load Custom Template') == 'Yes':
+            return get_document()
+        else:
+            return
+
 def load_xml_file(xml_file: str):
     with open(xml_file, 'r', encoding='utf-8') as file:
         xml = file.read()
     return get_xml_file(xml)
 
 def construct_full_ref(ab: et. _Element):
-    ref = ab.get(f'{XML_NS}id').replace('-APP', '') #type: str
+    ref = ab.get(f'{XML_NS}id').replace('-APP', '').upper() #type: str
     if ref.startswith('B'): # then it is an INTF/IGNTP style reference... probably
         book = re.search(r'B\d+', ref).group(0)
         book = ABBR_TO_FULL[book]
         chapter = re.search(r'K\d+', ref).group(0)
         verse = re.search(r'V\d+', ref).group(0)
-        ref = f'{book} {chapter}:{verse}'
+        ref = f'{book} {chapter.replace("K", "")}:{verse.replace("V", "")}'
     else:
         book = re.search(r'.[a-zA-Z]+', ref)
         if not book:
@@ -236,10 +245,16 @@ def print_rdg(
     rdg_n_text_separator: str, 
     text_bold: bool
     ):
-    if rdg.text:
-        greek_text = rdg.text
-    else:
+    if rdg.get('type') and rdg.text:
+        greek_text = f"{rdg.get('type')}\t{rdg.text}"
+    elif rdg.get('type'):
         greek_text = rdg.get('type')
+    else:
+        greek_text = rdg.text
+    # if rdg.text:
+    #     greek_text = rdg.text
+    # else:
+    #     greek_text = rdg.get('type')
     p = document.add_paragraph()
     p.style = document.styles['reading']
     rdg_name = re.sub(r'\d', '', rdg.get('n'))
@@ -259,7 +274,10 @@ def save_docx(document: Document, settings: dict):
         docx_filename = f'{docx_filename}.docx'
     docx_dir = Path(docx_filename).parent.as_posix()
     es.edit_settings('export_docx_folder', docx_dir)
-    document.save(docx_filename)
+    try:
+        document.save(docx_filename)
+    except PermissionError:
+        sg.popup_ok('You cannot overwrite a file that is currently open in another app.', 'Oopsie')
     return docx_filename
 
 def combine_regularized(app: et._Element):
@@ -275,22 +293,31 @@ def combine_regularized(app: et._Element):
 
     for parent, wits in reg_wits.items():
         wits = wits.split()
-        wits = [f'{w}r' for w in wits]
+        wits = [f'{w}' for w in wits]
         wits = ' '.join(wits)
         reg_wits[parent] = wits
 
+    previous = ''
     for rdg in app.findall(f'{TEI_NS}rdg'): #type: list[et._Element]
         if rdg.get('n') in reg_wits:
             combined = f'{rdg.get("wit")} {reg_wits[rdg.get("n")]}'.lstrip()
             rdg.attrib['wit'] = combined
+        elif 'r' in rdg.get('n') and rdg.get('n')[0] != previous[0]:
+            continue
         elif 'r' in rdg.get('n'):
             app.remove(rdg)
+        previous = rdg.get('n')
 
     return app
 
-def export_xml_to_docx(xml_filename: str, collapse_regularized: bool = False):
+def export_xml_to_docx(xml_filename: str, collapse_regularized: bool = False, use_custom_template: str = None):
     settings = es.get_settings()
-    document = get_document()
+    if use_custom_template:
+        document = get_custom_document(use_custom_template)
+    else:
+        document = get_document()
+    if not document:
+        return
     root = load_xml_file(xml_filename)
     for ab in root.findall(f'{TEI_NS}ab'):
         print_reference(document, ab)
