@@ -6,6 +6,7 @@ import PySimpleGUI as sg
 import criticus.py.edit_settings as es
 import criticus.py.custom_popups as cp
 from criticus.py.export_to_docx.xml_to_docx import export_xml_to_docx
+from criticus.py import edit_settings as es
 
 
 def unescape_string(text: str):
@@ -27,19 +28,28 @@ def update_settings(settings: dict, values: dict):
     settings['reformatted_xml_dir'] = Path(values['xml_filename']).parent.as_posix()
     es.save_settings(settings)
 
-def export(settings, values: dict, collapse_regularized: bool = False):
+def export(settings, values: dict, collapse_regularized: bool = False, use_custom_template: bool = None):
     if not validate_form(values):
         return
     update_settings(settings, values)
     # try:
-    saved_file = export_xml_to_docx(values['xml_filename'], collapse_regularized)
+    saved_file = export_xml_to_docx(values['xml_filename'], collapse_regularized, use_custom_template)
     if saved_file:
         cp.ok(f'Collation exported to {saved_file}', 'Success!')
     # except Exception as e:
     #     cp.ok(f'{e}', 'Failed to Export')
 
 def layout(settings: dict):
+    custom_template_path = es.get_settings()['custom_template_path']
+    if  custom_template_path != '':
+        template_parent = Path(custom_template_path).parent.as_posix()
+    else:
+        template_parent = None
+
     options_frame = [
+        [
+            sg.Checkbox('Use Custom Template', key='use_custom_template', enable_events=True), sg.Input(custom_template_path, key='custom_template_path', disabled=True), sg.FileBrowse(initial_folder=template_parent)
+        ],
         [
             sg.T('Reading Text and Witnesses Separator: '), 
             sg.I(settings.get('text_wits_separator', ' // '), key='text_wits_separator')
@@ -80,6 +90,13 @@ def export_to_docx(font, icon):
         event, values = window.read()
         if event in [None, sg.WIN_CLOSED, 'Close']:
             break
-        elif event == 'Export':
-            export(settings, values, values['collapse_regularized'])
+        elif event == 'Export' and not values['use_custom_template']:
+            export(settings, values, values['collapse_regularized'], None)
+
+        elif event == 'Export' and values['use_custom_template'] is True and values['custom_template_path'] != '':
+            export(settings, values, values['collapse_regularized'], values['custom_template_path'])
+            es.edit_settings('custom_template_path', values['custom_template_path'])
+
+        elif event == 'use_custom_template':
+            window['custom_template_path'].update(disabled=not values['use_custom_template'])
     window.close()
